==> libevdev-1.13.4.tar.xz: libevdev-1.13.4/doc/html/search/all_10.js <==
var searchData=
[
  ['safety_0',['Signal safety',['../index.html#autotoc_md2',1,'']]],
  ['setup_1',['Initialization and setup',['../group__init.html',1,'']]],
  ['signal_20safety_2',['Signal safety',['../index.html#autotoc_md2',1,'']]],
  ['sit_3',['Where does libevdev sit?',['../index.html#autotoc_md4',1,'']]],
  ['slot_20behavior_4',['MT slot behavior',['../backwardscompatibility.html#autotoc_md17',1,'']]],
  ['state_20of_20the_20device_5',['Synchronizing the state of the device',['../syn_dropped.html#autotoc_md11',1,'']]],
  ['statically_20linking_20libevdev_6',['Statically linking libevdev',['../static_linking.html',1,'']]],
  ['suite_7',['libevdev-internal test suite',['../testing.html',1,'']]],
  ['syn_5fdropped_8',['Handling events and SYN_DROPPED',['../index.html#autotoc_md1',1,'']]],
  ['syn_5fdropped_20behavior_9',['SYN_DROPPED behavior',['../backwardscompatibility.html#autotoc_md18',1,'']]],
  ['syn_5fdropped_20handling_10',['SYN_DROPPED handling',['../syn_dropped.html',1,'']]],
  ['syn_5fdropped_20tt_20events_11',['Receiving &lt;tt&gt;SYN_DROPPED&lt;/tt&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]],
  ['synchronizing_12',['Discarding events before synchronizing',['../syn_dropped.html#autotoc_md13',1,'']]],
  ['synchronizing_20abs_5fmt_5ftracking_5fid_13',['Synchronizing ABS_MT_TRACKING_ID',['../syn_dropped.html#autotoc_md12',1,'']]],
  ['synchronizing_20the_20state_20of_20the_20device_14',['Synchronizing the state of the device',['../syn_dropped.html#autotoc_md11',1,'']]]
];

==> libevdev-1.13.6.tar.xz: libevdev-1.13.6/doc/html/search/all_10.js <==
var searchData=
[
  ['safety_0',['Signal safety',['../index.html#autotoc_md2',1,'']]],
  ['setup_1',['Initialization and setup',['../group__init.html',1,'']]],
  ['signal_20safety_2',['Signal safety',['../index.html#autotoc_md2',1,'']]],
  ['sit_3',['Where does libevdev sit?',['../index.html#autotoc_md4',1,'']]],
  ['slot_20behavior_4',['MT slot behavior',['../backwardscompatibility.html#autotoc_md17',1,'']]],
  ['state_20of_20the_20device_5',['Synchronizing the state of the device',['../syn_dropped.html#autotoc_md11',1,'']]],
  ['statically_20linking_20libevdev_6',['Statically linking libevdev',['../static_linking.html',1,'']]],
  ['suite_7',['libevdev-internal test suite',['../testing.html',1,'']]],
  ['syn_5fdropped_8',['Handling events and SYN_DROPPED',['../index.html#autotoc_md1',1,'']]],
  ['syn_5fdropped_20behavior_9',['SYN_DROPPED behavior',['../backwardscompatibility.html#autotoc_md18',1,'']]],
  ['syn_5fdropped_20events_10',['Receiving &lt;span class=&quot;tt&quot;&gt;SYN_DROPPED&lt;/span&gt; events',['../syn_dropped.html#autotoc_md10',1,'']]],
  ['syn_5fdropped_20handling_11',['SYN_DROPPED handling',['../syn_dropped.html',1,'']]],
  ['synchronizing_12',['Discarding events before synchronizing',['../syn_dropped.html#autotoc_md13',1,'']]],
  ['synchronizing_20abs_5fmt_5ftracking_5fid_13',['Synchronizing ABS_MT_TRACKING_ID',['../syn_dropped.html#autotoc_md12',1,'']]],
  ['synchronizing_20the_20state_20of_20the_20device_14',['Synchronizing the state of the device',['../syn_dropped.html#autotoc_md11',1,'']]]
];
